database

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ClearLoginAttempts

func ClearLoginAttempts(t *testing.T, email string)

ClearLoginAttempts removes login attempt records to reset lockout state

func Exec

func Exec(t *testing.T, query string, args ...any)

Exec executes a SQL statement and fails the test on error

func GetPasswordResetToken

func GetPasswordResetToken(t *testing.T, email string) string

GetPasswordResetToken retrieves the password reset token for a user

func GetVerificationToken

func GetVerificationToken(t *testing.T, email string) string

GetVerificationToken retrieves the email verification token for a user

func QueryRow

func QueryRow(t *testing.T, query string, args ...any) pgx.Row

QueryRow executes a query that returns a single row

Types

This section is empty.

Jump to