Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClearLoginAttempts ¶
ClearLoginAttempts removes login attempt records to reset lockout state
func GetPasswordResetToken ¶
GetPasswordResetToken retrieves the password reset token for a user
func GetVerificationToken ¶
GetVerificationToken retrieves the email verification token for a user
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.